@@ -38,6 +38,7 @@ Fl_Menu_Item touch_menu[] = {
  {_("Transceiver"), 0,  (Fl_Callback*)cb_mnuConfigXcvr, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("tcpip"), 0, (Fl_Callback*)cb_mnuTCPIP, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT"), 0, (Fl_Callback*)cb_mnuPTT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("GPIO"), 0, (Fl_Callback*)cb_mnuGPIO, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Server"), 0, (Fl_Callback*)cb_mnuSERVER, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -344,28 +345,13 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		ypos = Y + 2;
 
 		FreqDispA = new cFreqControl(xpos, ypos, 480, 100, _("10"));
-		FreqDispA->box(FL_DOWN_BOX);
-		FreqDispA->color(FL_BACKGROUND_COLOR);
-		FreqDispA->selection_color(FL_BACKGROUND_COLOR);
 		FreqDispA->labeltype(FL_NORMAL_LABEL);
-		FreqDispA->labelfont(0);
-		FreqDispA->labelsize(14);
-		FreqDispA->labelcolor(FL_FOREGROUND_COLOR);
-		FreqDispA->align(Fl_Align(FL_ALIGN_CENTER));
 		FreqDispA->when(FL_WHEN_CHANGED);
 		FreqDispA->SetONOFFCOLOR (FL_YELLOW, FL_BLACK);
 		FreqDispA->setCallBack(movFreqA);
 
 // FreqDispB hides behind FreqDispA
-		FreqDispB = new cFreqControl(xpos, ypos, 480, 100, _("9"));
-		FreqDispB->box(FL_DOWN_BOX);
-		FreqDispB->color(FL_BACKGROUND_COLOR);
-		FreqDispB->selection_color(FL_BACKGROUND_COLOR);
-		FreqDispB->labeltype(FL_NORMAL_LABEL);
-		FreqDispB->labelfont(0);
-		FreqDispB->labelsize(14);
-		FreqDispB->labelcolor(FL_FOREGROUND_COLOR);
-		FreqDispB->align(Fl_Align(FL_ALIGN_CENTER));
+		FreqDispB = new cFreqControl(xpos, ypos, 480, 100, _("10"));
 		FreqDispB->when(FL_WHEN_CHANGED);
 		FreqDispB->SetONOFFCOLOR (FL_YELLOW, FL_BLACK);
 		FreqDispB->setCallBack(movFreqB);
@@ -729,14 +715,14 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		ypos += 15;
 		xpos = 2;
 
-		btnAttenuator = new Fl_Light_Button(xpos, ypos, bw, bh, _("Att"));
+		btnAttenuator = new Fl_Light_Button(xpos, ypos, bw, bh, _("ATT"));
 		btnAttenuator->tooltip(_("Attenuator On/Off"));
 		btnAttenuator->down_box(FL_THIN_DOWN_BOX);
 		btnAttenuator->labelsize(16);
 		btnAttenuator->callback((Fl_Callback*)cb_btnAttenuator);
 
 		xpos += btnAttenuator->w() + 2;
-		btnPreamp = new Fl_Light_Button(xpos, ypos, bw, bh, _("Pre"));
+		btnPreamp = new Fl_Light_Button(xpos, ypos, bw, bh, _("PRE"));
 		btnPreamp->tooltip(_("Preamp On/Off"));
 		btnPreamp->down_box(FL_THIN_DOWN_BOX);
 		btnPreamp->labelsize(16);
@@ -816,7 +802,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 
 			tabsGeneric->selection_color(FL_LIGHT1);
 
-			tab_yaesu_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Bands"));
+			tab_yaesu_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Band"));
 
 				btn_yaesu_select_1 = new Fl_Button(xpos+4, by, 50, bh, _("1.8"));
 				btn_yaesu_select_1->tooltip(_("160m Band"));
@@ -891,7 +877,89 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 
 			tab_yaesu_bands->end();
 
-			tab_FT8n_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Bands"));
+			tab_ft991_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Band"));
+
+				btn_ft991_select_1 = new Fl_Button(xpos+4, by, 50, bh, _("1.8"));
+				btn_ft991_select_1->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_1->color((Fl_Color)246);
+				btn_ft991_select_1->callback((Fl_Callback*)cb_btn_band_select, (void *)1);
+
+				btn_ft991_select_2 = new Fl_Button(xpos+58, by, 50, bh, _("3.5"));
+				btn_ft991_select_2->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_2->color((Fl_Color)246);
+				btn_ft991_select_2->callback((Fl_Callback*)cb_btn_band_select, (void *)2);
+
+				btn_ft991_select_3 = new Fl_Button(xpos+112, by, 50, bh, _("7"));
+				btn_ft991_select_3->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_3->color((Fl_Color)246);
+				btn_ft991_select_3->callback((Fl_Callback*)cb_btn_band_select, (void *)3);
+				btn_ft991_select_3->align(Fl_Align(FL_ALIGN_CLIP));
+
+				btn_ft991_select_4 = new Fl_Button(xpos+166, by, 50, bh, _("10"));
+				btn_ft991_select_4->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_4->color((Fl_Color)246);
+				btn_ft991_select_4->callback((Fl_Callback*)cb_btn_band_select, (void *)4);
+
+				btn_ft991_select_5 = new Fl_Button(xpos+220, by, 50, bh, _("14"));
+				btn_ft991_select_5->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_5->color((Fl_Color)246);
+				btn_ft991_select_5->callback((Fl_Callback*)cb_btn_band_select, (void *)5);
+
+				btn_ft991_select_6 = new Fl_Button(xpos+274, by, 50, bh, _("18"));
+				btn_ft991_select_6->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_6->color((Fl_Color)246);
+				btn_ft991_select_6->callback((Fl_Callback*)cb_btn_band_select, (void *)6);
+
+				btn_ft991_select_7 = new Fl_Button(xpos+328, by, 50, bh, _("21"));
+				btn_ft991_select_7->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_7->color((Fl_Color)246);
+				btn_ft991_select_7->callback((Fl_Callback*)cb_btn_band_select, (void *)7);
+
+				btn_ft991_select_8 = new Fl_Button(xpos+372, by, 50, bh, _("24"));
+				btn_ft991_select_8->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_8->color((Fl_Color)246);
+				btn_ft991_select_8->callback((Fl_Callback*)cb_btn_band_select, (void *)8);
+
+				btn_ft991_select_9 = new Fl_Button(xpos+426, by, 50, bh, _("28"));
+				btn_ft991_select_9->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_9->color((Fl_Color)246);
+				btn_ft991_select_9->callback((Fl_Callback*)cb_btn_band_select, (void *)9);
+
+				btn_ft991_select_10 = new Fl_Button(xpos+480, by, 50, bh, _("50"));
+				btn_ft991_select_10->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_10->color((Fl_Color)246);
+				btn_ft991_select_10->callback((Fl_Callback*)cb_btn_band_select, (void *)10);
+
+				btn_ft991_select_11 = new Fl_Button(xpos+534, by, 50, bh, _("144"));
+				btn_ft991_select_11->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_11->color((Fl_Color)246);
+				btn_ft991_select_11->callback((Fl_Callback*)cb_btn_band_select, (void *)11);
+
+				btn_ft991_select_12 = new Fl_Button(xpos+ 588, by, 50, bh, _("440"));
+				btn_ft991_select_12->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_12->color((Fl_Color)246);
+				btn_ft991_select_12->callback((Fl_Callback*)cb_btn_band_select, (void *)12);
+
+				btn_ft991_select_13 = new Fl_Button(xpos+ 642, by, 50, bh, _("Gen"));
+				btn_ft991_select_13->tooltip(_("Left click - get\nRight click - set"));
+				btn_ft991_select_13->color((Fl_Color)246);
+				btn_ft991_select_13->callback((Fl_Callback*)cb_btn_band_select, (void *)13);
+
+				choice_ft991_tTONE = new Fl_PL_tone(xpos+ 696, by, 75, bh, _("tTONE"));
+				choice_ft991_tTONE->align((Fl_Align)FL_ALIGN_BOTTOM);
+				choice_ft991_tTONE->value(8);
+				choice_ft991_tTONE->end();
+				choice_ft991_tTONE->hide();
+
+				choice_ft991_rTONE = new Fl_PL_tone(xpos+ 775, by, 75, bh, _("rTONE"));
+				choice_ft991_rTONE->align((Fl_Align)FL_ALIGN_BOTTOM);
+				choice_ft991_rTONE->value(8);
+				choice_ft991_rTONE->end();
+				choice_ft991_rTONE->hide();
+
+			tab_ft991_bands->end();
+
+			tab_FT8n_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Band"));
 			static const char setsave[] = _("Left click - set\nRight click - save");
 				btn_FT8n_select_1 = new Fl_Button(xpos+4, by, 50, bh, _("1.8"));
 				btn_FT8n_select_1->tooltip(setsave);
@@ -995,7 +1063,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 
 			tab_FT8n_CTCSS->end();
 
-			tab_icom_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Bands"));
+			tab_icom_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Band"));
 
 				btn_icom_select_1 = new Fl_Button(xpos+4, by, 50, bh, _("1.8"));
 				btn_icom_select_1->tooltip(_("Left click - get\nRight click - set"));
@@ -1230,7 +1298,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 			genericSpeech = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Spch"));
 				genericSpeech->hide();
 
-				btnCompON = new Fl_Light_Button(xpos+230, by, 70, bh, _("On"));
+				btnCompON = new Fl_Light_Button(xpos+230, by, 100, bh, _("On"));
 				btnCompON->callback((Fl_Callback*)cb_btnCompON);
 				btnCompON->value(progStatus.compON);
 				btnCompON->tooltip(_("Compression on/off"));
@@ -1433,7 +1501,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 
 			genericAux->end();
 
-			genericUser_1 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("User A"));
+			genericUser_1 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Cmd A"));
 				genericUser_1->hide();
 
 				btnUser1 = new Fl_Button(5, by, 80, 50, "USER 1");
@@ -1462,7 +1530,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 
 			genericUser_1->end();
 
-			genericUser_2 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("User B"));
+			genericUser_2 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Cmd B"));
 				genericUser_2->hide();
 
 				btnUser9 = new Fl_Button(5, by, 80, 50, "USER 9");
@@ -1491,6 +1559,35 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 
 			genericUser_2->end();
 
+			genericUser_3 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Cmd C"));
+				genericUser_3->hide();
+
+				btnUser17 = new Fl_Button(5, by, 80, 50, "USER 9");
+				btnUser17->callback((Fl_Callback*)cb_btnUser, (void*)9);
+
+				btnUser18 = new Fl_Button(90, by, 80, 50, "USER 10");
+				btnUser18->callback((Fl_Callback*)cb_btnUser, (void*)10);
+
+				btnUser19 = new Fl_Button(175, by, 80, 50, "USER 11");
+				btnUser19->callback((Fl_Callback*)cb_btnUser, (void*)11);
+
+				btnUser20 = new Fl_Button(260, by, 80, 50, "USER 12");
+				btnUser20->callback((Fl_Callback*)cb_btnUser, (void*)12);
+
+				btnUser21 = new Fl_Button(345, by, 80, 50, "USER 13");
+				btnUser21->callback((Fl_Callback*)cb_btnUser, (void*)13);
+
+				btnUser22 = new Fl_Button(430, by, 80, 50, "USER 14");
+				btnUser22->callback((Fl_Callback*)cb_btnUser, (void*)14);
+
+				btnUser23 = new Fl_Button(515, by, 80, 50, "USER 15");
+				btnUser23->callback((Fl_Callback*)cb_btnUser, (void*)15);
+
+				btnUser24 = new Fl_Button(600, by, 80, 50, "USER 16");
+				btnUser24->callback((Fl_Callback*)cb_btnUser, (void*)16);
+
+			genericUser_3->end();
+
 			tab7610 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("IC7610"));
 				ic7610att = new Fl_ComboBox(5, by, 120, 50, "Att level");
 				ic7610att->add("OFF|3db|6db|9db|12db|15db|18db|21db|24db|27db|30db|33db|36db|39db|42db|45db|");
