@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "IC746.h"
@@ -161,7 +161,7 @@ bool RIG_IC746::check ()
 	return ok;
 }
 
-long RIG_IC746::get_vfoA ()
+unsigned long int RIG_IC746::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string cstr = "\x03";
@@ -172,13 +172,17 @@ long RIG_IC746::get_vfoA ()
 	cmd.append(post);
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return A.freq;
 }
 
-void RIG_IC746::set_vfoA (long freq)
+void RIG_IC746::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -188,7 +192,7 @@ void RIG_IC746::set_vfoA (long freq)
 	waitFB("set vfo A");
 }
 
-long RIG_IC746::get_vfoB ()
+unsigned long int RIG_IC746::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string cstr = "\x03";
@@ -199,13 +203,17 @@ long RIG_IC746::get_vfoB ()
 	cmd.append(post);
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return B.freq;
 }
 
-void RIG_IC746::set_vfoB (long freq)
+void RIG_IC746::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -474,9 +482,12 @@ int RIG_IC746::get_modeA()
 	if (waitFOR(8, "get mode A")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			A.imode = replystr[p+5];
-			if (A.imode > 6) A.imode--;
-			filter_nbr = replystr[p+6] - 1;
+			if (replystr[p+5] == -1) { A.imode = filter_nbr = 0; }
+			else {
+				A.imode = replystr[p+5];
+				if (A.imode > 6) A.imode--;
+				filter_nbr = replystr[p+6] - 1;
+			}
 		}
 	}
 	return A.imode;
@@ -515,9 +526,12 @@ int RIG_IC746::get_modeB()
 	if (waitFOR(8, "get mode B")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			B.imode = replystr[p+5];
-			if (B.imode > 6) B.imode--;
-			filter_nbr = replystr[p+6] - 1;
+			if (replystr[p+5] == -1) { B.imode = filter_nbr = 0; }
+			else {
+				B.imode = replystr[p+5];
+				if (B.imode > 6) B.imode--;
+				filter_nbr = replystr[p+6] - 1;
+			}
 		}
 	}
 	return B.imode;
@@ -642,7 +656,7 @@ int RIG_IC746::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -1432,7 +1446,7 @@ int RIG_IC746PRO::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -1494,7 +1508,7 @@ void RIG_IC746PRO::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1524,7 +1538,7 @@ void RIG_IC746PRO::get_band_selection(int v)
 
 void RIG_IC746PRO::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int fil = (useB ? filB : filA);
 	int mode = (useB ? B.imode : A.imode);
 
