@@ -27,6 +27,8 @@
 #include <FL/Fl_Progress.H>
 #include <FL/Enumerations.H>
 
+#include "dialogs.h"
+
 #include "status.h"
 #include "util.h"
 #include "rig.h"
@@ -49,6 +51,15 @@ status progStatus = {
 	150,		// int mainH;
 	small_ui,	// UISIZE, UIsize;
 	false,		// UIchanged;
+
+	20,			// int memX;
+	20,			// int memY;
+	600,		// int memW;
+	164,		// int memH;
+
+	20,			// int ddX;
+	20,			// int ddY;
+
 	"NONE",		// string xcvr_serial_port;
 	0,			// int comm_baudrate;
 	2,			// int stopbits;
@@ -108,6 +119,7 @@ status progStatus = {
 	1,			// poll_ops;
 	1,			// poll_compression;
 	1,			// poll_tuner;
+	1,			// poll_ptt;
 	4,			// int	poll_all;
 
 	-1,			// int  iBW_A;
@@ -321,7 +333,33 @@ status progStatus = {
 	"",				// string	command16;
 	"",				// string	shftcmd16;
 
+	"cmd 17",		// string	label17;
+	"",				// string	command17;
+	"",				// string	shftcmd17;
+	"cmd 18",		// string	label18;
+	"",				// string	command18;
+	"",				// string	shftcmd18;
+	"cmd 19",		// string	label19;
+	"",				// string	command19;
+	"",				// string	shftcmd19;
+	"cmd 20",		// string	label20;
+	"",				// string	command20;
+	"",				// string	shftcmd20;
+	"cmd 21",		// string	label21;
+	"",				// string	command21;
+	"",				// string	shftcmd21;
+	"cmd 22",		// string	label22;
+	"",				// string	command22;
+	"",				// string	shftcmd22;
+	"cmd 23",		// string	label23;
+	"",				// string	command23;
+	"",				// string	shftcmd23;
+	"cmd 24",		// string	label24;
+	"",				// string	command24;
+	"",				// string	shftcmd24;
+
 // =========================
+
 	232,		// int	 bg_red;
 	255,		// int	 bg_green;
 	232,		// int	 bg_blue;
@@ -402,20 +440,32 @@ status progStatus = {
 	false,		// bool	start_stop_trace;
 	0,			// int	rpc_level;
 
-// bands; defaults for FT857 / FT897
+// bands; defaults for FT857 / FT897 / Xiegu-G90
 // frequency, mode, txCTCSS, rxCTCSS, offset, offset_freq;
-	1805000L, 6, 0, 0, 0, 600, 		// f160
-	3580000L, 6, 0, 0, 0, 600,		// f80 meters
-	7070000L, 6, 0, 0, 0, 600,		// f40 meters
-	10140000L, 6, 0, 0, 0, 600,		// f30 meters
-	14070000L, 6, 0, 0, 0, 600,		// f20 meters
-	18100000L, 6, 0, 0, 0, 600,		// f17 meters
-	21070000L, 6, 0, 0, 0, 600,		// f15 meters
-	24920000L, 6, 0, 0, 0, 600,		// f12 meters
-	28070000L, 6, 0, 0, 0, 600,		// f10 meters
-	50070000L, 6, 0, 0, 0, 600,		// f6 meters
-	144070000L, 6, 0, 0, 0, 600,	// f2 meters
-	432100000L, 6, 0, 0, 0, 600,		// f70 cent'
+	1805000L, 0, 0, 0, 0, 600, 		// f160
+	3580000L, 0, 0, 0, 0, 600,		// f80 meters
+	7070000L, 0, 0, 0, 0, 600,		// f40 meters
+	10140000L, 0, 0, 0, 0, 600,		// f30 meters
+	14070000L, 0, 0, 0, 0, 600,		// f20 meters
+	18100000L, 0, 0, 0, 0, 600,		// f17 meters
+	21070000L, 0, 0, 0, 0, 600,		// f15 meters
+	24920000L, 0, 0, 0, 0, 600,		// f12 meters
+	28070000L, 0, 0, 0, 0, 600,		// f10 meters
+	50070000L, 0, 0, 0, 0, 600,		// f6 meters
+	144070000L, 0, 0, 0, 0, 600,	// f2 meters
+	432100000L, 0, 0, 0, 0, 600,	// f70 cent'
+	1210000000L, 0, 0, 0, 0, 600,	// f12G
+	15000000L, 0, 0, 0, 0, 600,		// general
+
+// memory management
+	4,								// Fl_Font	memfontnbr;
+	14,								// int		memfontsize;
+
+// gpio parameters
+	false,		// bool	gpio_ptt;
+	0,			// int	enable_gpio;
+	0,			// int	gpio_on;
+	0,			//int	gpio_pulse_width;
 
 // cwio parameters
 	20,			// int    cwioWPM;
@@ -433,17 +483,23 @@ void status::saveLastState()
 	xcvr_name = selrig->name_;
 	Fl_Preferences xcvrpref(RigHomeDir.c_str(), "w1hkj.com", PACKAGE_TARNAME);
 	xcvrpref.set("xcvr_name", xcvr_name.c_str());
-//	xcvrpref.set("xml_port", xmlport);
 
 	int mX = mainwindow->x();
 	int mY = mainwindow->y();
 	int mW = mainwindow->w();
 	int mH = mainwindow->h();
 
+	if (dlgMemoryDialog) {
+		memX = dlgMemoryDialog->x();
+		memY = dlgMemoryDialog->y();
+		memW = dlgMemoryDialog->w();
+		memH = dlgMemoryDialog->h();
+	}
+
 	if (mX >= 0 && mX >= 0) {
 		mainX = mX;
 		mainY = mY;
-		if (UIsize != small_ui) { mainW = mW; mainH = mH; }
+		if (UIsize == touch_ui || UIsize == wide_ui) { mainW = mW; mainH = mH; }
 	}
 
 	Fl_Preferences spref(RigHomeDir.c_str(), "w1hkj.com", xcvr_name.c_str());
@@ -457,6 +513,14 @@ void status::saveLastState()
 
 	spref.set("uisize", UIsize);
 
+	spref.set("memx", memX);
+	spref.set("memy", memY);
+	spref.set("memw", memW);
+	spref.set("memh", memH);
+
+	spref.set("ddx", ddX);
+	spref.set("ddy", ddY);
+
 	spref.set("xcvr_serial_port", xcvr_serial_port.c_str());
 	spref.set("comm_baudrate", comm_baudrate);
 	spref.set("comm_stopbits", stopbits);
@@ -512,6 +576,7 @@ void status::saveLastState()
 	spref.set("poll_nr", poll_nr);
 	spref.set("poll_compression", poll_compression);
 	spref.set("poll_tuner", poll_tuner);
+	spref.set("poll_ptt", poll_ptt);
 	spref.set("poll_all", poll_all);
 
 	spref.set("bw_A", iBW_A);
@@ -749,6 +814,38 @@ void status::saveLastState()
 	spref.set("command16", command16.c_str());
 	spref.set("shftcmd16", shftcmd16.c_str());
 
+	spref.set("label17", label17.c_str());
+	spref.set("command17", command17.c_str());
+	spref.set("shftcmd17", shftcmd17.c_str());
+
+	spref.set("label18", label18.c_str());
+	spref.set("command18", command18.c_str());
+	spref.set("shftcmd18", shftcmd18.c_str());
+
+	spref.set("label19", label19.c_str());
+	spref.set("command19", command19.c_str());
+	spref.set("shftcmd19", shftcmd19.c_str());
+
+	spref.set("label20", label20.c_str());
+	spref.set("command20", command20.c_str());
+	spref.set("shftcmd20", shftcmd20.c_str());
+
+	spref.set("label21", label21.c_str());
+	spref.set("command21", command21.c_str());
+	spref.set("shftcmd21", shftcmd21.c_str());
+
+	spref.set("label22", label22.c_str());
+	spref.set("command22", command22.c_str());
+	spref.set("shftcmd22", shftcmd22.c_str());
+
+	spref.set("label23", label23.c_str());
+	spref.set("command23", command23.c_str());
+	spref.set("shftcmd23", shftcmd23.c_str());
+
+	spref.set("label24", label24.c_str());
+	spref.set("command24", command24.c_str());
+	spref.set("shftcmd24", shftcmd24.c_str());
+
 	spref.set("fg_red", fg_red);
 	spref.set("fg_green", fg_green);
 	spref.set("fg_blue", fg_blue);
@@ -868,6 +965,14 @@ void status::saveLastState()
 	spref.set("hrd_buttons", hrd_buttons);
 	spref.set("sliders_button", sliders_button);
 
+	spref.set("memfontnbr", memfontnbr);
+	spref.set("memfontsize", memfontsize);
+
+	spref.set("gpio_ptt", gpio_ptt);
+	spref.set("enable_gpio", enable_gpio);
+	spref.set("gpio_on", gpio_on);
+	spref.set("gpio_pulse_width", gpio_pulse_width);
+
 	spref.set("cwioWPM", cwioWPM);
 	spref.set("cwio_comp", cwio_comp);
 	spref.set("cwioKEYLINE", cwioKEYLINE);
@@ -899,12 +1004,24 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("mainw", mainW, mainW);
 		spref.get("mainh", mainH, mainH);
 		spref.get("uisize", UIsize, UIsize);
+
+		spref.get("memx", memX, memX);
+		spref.get("memy", memY, memY);
+		spref.get("memw", memW, memW);
+		spref.get("memh", memH, memH);
+
+		spref.get("ddX", ddX, ddX);
+		spref.get("ddY", ddY, ddY);
+
 		if (current_ui_size != -1) {
 			UIsize = current_ui_size;
 		}
 		current_ui_size = UIsize;
 		if (UIsize == wide_ui) {
-			if (mainW < WIDE_MAINW) mainW = WIDE_MAINW;
+			mainW = progStatus.mainW;//WIDE_MAINW;
+		}
+		if (UIsize == small_ui) {
+			mainW = SMALL_MAINW;
 		}
 		if (UIsize == touch_ui) {
 			if (mainW < TOUCH_MAINW) mainW = TOUCH_MAINW;
@@ -986,6 +1103,7 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("poll_nr", poll_nr, poll_nr);
 		spref.get("poll_compression", poll_compression, poll_compression);
 		spref.get("poll_tuner", poll_tuner, poll_tuner);
+		spref.get("poll_ptt", poll_ptt, poll_ptt);
 		spref.get("poll_all", poll_all, poll_all);
 
 		spref.get("bw_A", iBW_A, iBW_A);
@@ -996,7 +1114,6 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("freq_A_u", freq_A_upper, freq_A_upper);
 		spref.get("freq_A_l", freq_A_lower, freq_A_lower);
 		freq_A = (unsigned long int)freq_A_upper * 1000000000 + freq_A_lower;
-std::cout << "freq A: " << freq_A << std::endl;
 
 		spref.get("bw_B", iBW_B, iBW_B);
 		spref.get("mode_B", imode_B, imode_B);
@@ -1006,7 +1123,6 @@ std::cout << "freq A: " << freq_A << std::endl;
 		spref.get("freq_B_u", freq_B_upper, freq_B_upper);
 		spref.get("freq_B_l", freq_B_lower, freq_B_lower);
 		freq_B = (unsigned long int)freq_B_upper * 1000000000 + freq_B_lower;
-std::cout << "freq B: " << freq_B << std::endl;
 
 		spref.get("filters", defbuffer, "", 499);
 		filters = defbuffer;
@@ -1277,6 +1393,62 @@ std::cout << "freq B: " << freq_B << std::endl;
 		spref.get("shftcmd16", defbuffer, shftcmd16.c_str(), 499);
 		shftcmd16 = defbuffer;
 
+		spref.get("label17", defbuffer,  label17.c_str(), 499);
+		label17 = defbuffer;
+		spref.get("command17", defbuffer, command17.c_str(), 499);
+		command17 = defbuffer;
+		spref.get("shftcmd17", defbuffer, shftcmd17.c_str(), 499);
+		shftcmd17 = defbuffer;
+
+		spref.get("label18", defbuffer, label18.c_str(), 499);
+		label18 = defbuffer;
+		spref.get("command18", defbuffer, command18.c_str(), 499);
+		command18 = defbuffer;
+		spref.get("shftcmd18", defbuffer, shftcmd18.c_str(), 499);
+		shftcmd18 = defbuffer;
+
+		spref.get("label19", defbuffer, label19.c_str(), 499);
+		label19 = defbuffer;
+		spref.get("command19", defbuffer, command19.c_str(), 499);
+		command19 = defbuffer;
+		spref.get("shftcmd19", defbuffer, shftcmd11.c_str(), 499);
+		shftcmd19 = defbuffer;
+
+		spref.get("label20", defbuffer, label20.c_str(), 499);
+		label20 = defbuffer;
+		spref.get("command20", defbuffer, command20.c_str(), 499);
+		command20 = defbuffer;
+		spref.get("shftcmd20", defbuffer, shftcmd20.c_str(), 499);
+		shftcmd20 = defbuffer;
+
+		spref.get("label21", defbuffer, label21.c_str(), 499);
+		label21 = defbuffer;
+		spref.get("command21", defbuffer, command21.c_str(), 499);
+		command21 = defbuffer;
+		spref.get("shftcmd21", defbuffer, shftcmd21.c_str(), 499);
+		shftcmd21 = defbuffer;
+
+		spref.get("label22", defbuffer, label22.c_str(), 499);
+		label22 = defbuffer;
+		spref.get("command22", defbuffer, command22.c_str(), 499);
+		command22 = defbuffer;
+		spref.get("shftcmd22", defbuffer, shftcmd22.c_str(), 499);
+		shftcmd22 = defbuffer;
+
+		spref.get("label23", defbuffer, label23.c_str(), 499);
+		label23 = defbuffer;
+		spref.get("command23", defbuffer, command23.c_str(), 499);
+		command23 = defbuffer;
+		spref.get("shftcmd23", defbuffer, shftcmd23.c_str(), 499);
+		shftcmd23 = defbuffer;
+
+		spref.get("label24", defbuffer, label24.c_str(), 499);
+		label24 = defbuffer;
+		spref.get("command24", defbuffer, command24.c_str(), 499);
+		command24 = defbuffer;
+		spref.get("shftcmd24", defbuffer, shftcmd24.c_str(), 499);
+		shftcmd24 = defbuffer;
+
 		spref.get("fg_red", fg_red, fg_red);
 		spref.get("fg_green", fg_green, fg_green);
 		spref.get("fg_blue", fg_blue, fg_blue);
@@ -1403,6 +1575,14 @@ std::cout << "freq B: " << freq_B << std::endl;
 		if (spref.get("hrd_buttons", i, i)) hrd_buttons = i;
 		spref.get("sliders_button", sliders_button, sliders_button);
 
+		spref.get("memfontnbr", memfontnbr, memfontnbr);
+		spref.get("memfontsize", memfontsize, memfontsize);
+
+		if (spref.get("gpio_ptt", i, i)) gpio_ptt = i;
+		spref.get("enable_gpio", enable_gpio, enable_gpio);
+		spref.get("gpio_on", gpio_on, gpio_on);
+		spref.get("gpio_pulse_width", gpio_pulse_width, gpio_pulse_width);
+
 		spref.get("cwioWPM", cwioWPM, cwioWPM);
 		spref.get("cwio_comp", cwio_comp, cwio_comp);
 		spref.get("cwioKEYLINE", cwioKEYLINE, cwioKEYLINE);
@@ -1583,6 +1763,15 @@ void status::UI_laststate()
 	btnUser15->label(label15.c_str()); btnUser15->redraw_label();
 	btnUser16->label(label16.c_str()); btnUser16->redraw_label();
 
+	btnUser17->label(label17.c_str()); btnUser17->redraw_label();
+	btnUser18->label(label18.c_str()); btnUser18->redraw_label();
+	btnUser19->label(label19.c_str()); btnUser19->redraw_label();
+	btnUser20->label(label20.c_str()); btnUser20->redraw_label();
+	btnUser21->label(label21.c_str()); btnUser21->redraw_label();
+	btnUser22->label(label22.c_str()); btnUser22->redraw_label();
+	btnUser23->label(label23.c_str()); btnUser23->redraw_label();
+	btnUser24->label(label24.c_str()); btnUser24->redraw_label();
+
 	Fl::scheme(ui_scheme.c_str());
 }
 
@@ -1639,6 +1828,7 @@ string status::info()
 	info << "poll_split         : " << poll_split << "\n";
 	info << "poll_noise         : " << poll_noise << "\n";
 	info << "poll_nr            : " << poll_nr << "\n";
+	info << "poll_ptt           : " << poll_ptt << "\n";
 	info << "poll_all           : " << poll_all << "\n";
 	info << "\n";
 	info << "freq_A             : " << freq_A << "\n";
@@ -1726,6 +1916,22 @@ string status::info()
 	info << "command 15         : " << command15 << "\n";
 	info << "label 16           : " << label16 << "\n";
 	info << "command 16         : " << command16 << "\n";
+	info << "label 17           : " << label17 << "\n";
+	info << "command 17         : " << command17 << "\n";
+	info << "label 18           : " << label18 << "\n";
+	info << "command 18         : " << command18 << "\n";
+	info << "label 19           : " << label19 << "\n";
+	info << "command 19         : " << command19 << "\n";
+	info << "label 20           : " << label20 << "\n";
+	info << "command 20         : " << command20 << "\n";
+	info << "label 21           : " << label21 << "\n";
+	info << "command 21         : " << command21 << "\n";
+	info << "label 22           : " << label22 << "\n";
+	info << "command 22         : " << command22 << "\n";
+	info << "label 23           : " << label23 << "\n";
+	info << "command 23         : " << command23 << "\n";
+	info << "label 24           : " << label24 << "\n";
+	info << "command 24         : " << command24 << "\n";
 
 	return info.str();
 }
